@@ -6,10 +6,12 @@ from typing import Any, Dict, List
 from hyperstyle.src.python.review.common.file_system import check_set_up_env_variable, new_temp_dir
 from hyperstyle.src.python.review.common.subprocess_runner import run_in_subprocess
 from hyperstyle.src.python.review.inspectors.base_inspector import BaseInspector
+from hyperstyle.src.python.review.inspectors.common.xml_parser import parse_xml_file_result
+from hyperstyle.src.python.review.inspectors.detekt.issue_configs import ISSUE_CONFIGS
 from hyperstyle.src.python.review.inspectors.detekt.issue_types import DETEKT_CLASS_NAME_TO_ISSUE_TYPE
 from hyperstyle.src.python.review.inspectors.inspector_type import InspectorType
 from hyperstyle.src.python.review.inspectors.issue import BaseIssue, IssueDifficulty, IssueType
-from hyperstyle.src.python.review.inspectors.parsers.xml_parser import parse_xml_file_result
+from hyperstyle.src.python.review.inspectors.issue_configs import IssueConfigsHandler
 
 logger = logging.getLogger(__name__)
 
@@ -23,15 +25,6 @@ PATH_DETEKT_CONFIG = PATH_TOOLS_PMD_FILES / 'detekt-config.yml'
 class DetektInspector(BaseInspector):
     inspector_type = InspectorType.DETEKT
 
-    origin_class_to_pattern = {
-        'LongMethod':
-            r'The function .* is too long \((\d+)\)',
-        'ComplexCondition':
-            r'This condition is too complex \((\d+)\)',
-        'ComplexMethod':
-            r'The function .* appears to be too complex \((\d+)\)',
-    }
-
     @classmethod
     def _create_command(cls, path: Path, output_path: Path):
         path_to_detekt_cli = f'{os.environ[DETEKT_DIRECTORY_ENV]}' \
@@ -52,17 +45,19 @@ class DetektInspector(BaseInspector):
         if not (check_set_up_env_variable(DETEKT_DIRECTORY_ENV) and check_set_up_env_variable(DETEKT_VERSION_ENV)):
             return []
 
+        issue_configs_handler = IssueConfigsHandler(*ISSUE_CONFIGS)
         with new_temp_dir() as temp_dir:
             output_path = temp_dir / 'output.xml'
             command = self._create_command(path, output_path)
 
             run_in_subprocess(command)
-            return parse_xml_file_result(output_path,
-                                         self.inspector_type,
-                                         self.choose_issue_type,
-                                         IssueDifficulty.get_by_issue_type,
-                                         self.origin_class_to_pattern,
-                                         {})
+            return parse_xml_file_result(
+                output_path,
+                self.inspector_type,
+                self.choose_issue_type,
+                IssueDifficulty.get_by_issue_type,
+                issue_configs_handler,
+            )
 
     @classmethod
     def choose_issue_type(cls, issue_class: str) -> IssueType:
