@@ -49,15 +49,13 @@ PMD_RULE_TO_ISSUE_TYPE: Dict[str, IssueType] = {
     # 'LooseCoupling': IssueType.BEST_PRACTICES,
     # 'PositionLiteralsFirstInCaseInsensitiveComparisons': IssueType.BEST_PRACTICES,
     # 'PositionLiteralsFirstInComparisons': IssueType.BEST_PRACTICES,
+    # 'PrimitiveWrapperInstantiation': IssueType.BEST_PRACTICES,
     # 'ReplaceHashtableWithMap': IssueType.BEST_PRACTICES,
     # 'ReplaceVectorWithList': IssueType.BEST_PRACTICES,
+    'SimplifiableTestAssertion': IssueType.BEST_PRACTICES,
     # 'SystemPrintln': IssueType.BEST_PRACTICES,
     # 'UnusedAssignment': IssueType.BEST_PRACTICES,
     # 'UnusedImports': IssueType.BEST_PRACTICES,
-    # 'UseAssertEqualsInsteadOfAssertTrue': IssueType.BEST_PRACTICES,
-    # 'UseAssertNullInsteadOfAssertTrue': IssueType.BEST_PRACTICES,
-    # 'UseAssertSameInsteadOfAssertTrue': IssueType.BEST_PRACTICES,
-    # 'UseAssertTrueInsteadOfAssertEquals': IssueType.BEST_PRACTICES,
     # 'UseVarargs': IssueType.BEST_PRACTICES,
 
     # ---- Code Style ----
@@ -129,7 +127,6 @@ PMD_RULE_TO_ISSUE_TYPE: Dict[str, IssueType] = {
     'GodClass': IssueType.COMPLEXITY,
     'LogicInversion': IssueType.BEST_PRACTICES,
     'SimplifiedTernary': IssueType.BEST_PRACTICES,
-    'SimplifyBooleanAssertion': IssueType.BEST_PRACTICES,
     'SimplifyBooleanExpressions': IssueType.BEST_PRACTICES,
     'SimplifyBooleanReturns': IssueType.BEST_PRACTICES,
     'SimplifyConditional': IssueType.BEST_PRACTICES,
@@ -216,17 +213,17 @@ PMD_RULE_TO_ISSUE_TYPE: Dict[str, IssueType] = {
     'FinalizeOverloaded': IssueType.ERROR_PRONE,
     'FinalizeShouldBeProtected': IssueType.ERROR_PRONE,
     'IdempotentOperations': IssueType.BEST_PRACTICES,
+    'ImplicitSwitchFallThrough': IssueType.ERROR_PRONE,
     'InstantiationToGetClass': IssueType.BEST_PRACTICES,
     'JumbledIncrementer': IssueType.ERROR_PRONE,
     'MethodWithSameNameAsEnclosingClass': IssueType.BEST_PRACTICES,
     'MisplacedNullCheck': IssueType.ERROR_PRONE,
-    'MissingBreakInSwitch': IssueType.ERROR_PRONE,
     # 'MissingSerialVersionUID': IssueType.ERROR_PRONE,
     'MissingStaticMethodInNonInstantiatableClass': IssueType.ERROR_PRONE,
     'NonCaseLabelInSwitchStatement': IssueType.BEST_PRACTICES,
     'OverrideBothEqualsAndHashcode': IssueType.ERROR_PRONE,
     'ProperCloneImplementation': IssueType.ERROR_PRONE,
-    'ReturnEmptyArrayRatherThanNull': IssueType.ERROR_PRONE,
+    'ReturnEmptyCollectionRatherThanNull': IssueType.ERROR_PRONE,
     'ReturnFromFinallyBlock': IssueType.BEST_PRACTICES,
     'SimpleDateFormatNeedsLocale': IssueType.BEST_PRACTICES,
     'SingleMethodSingleton': IssueType.ERROR_PRONE,
@@ -299,7 +296,6 @@ PMD_RULE_TO_ISSUE_TYPE: Dict[str, IssueType] = {
     'OptimizableToArrayCall': IssueType.BEST_PRACTICES,
     'StringToString': IssueType.BEST_PRACTICES,
     'TooFewBranchesForASwitchStatement': IssueType.BEST_PRACTICES,
-    'UnnecessaryWrapperObjectCreation': IssueType.BEST_PRACTICES,
     'UseArraysAsList': IssueType.BEST_PRACTICES,
     'UselessStringValueOf': IssueType.BEST_PRACTICES,
     'UseStringBufferLength': IssueType.BEST_PRACTICES,
@@ -309,14 +305,9 @@ PMD_RULE_TO_ISSUE_TYPE: Dict[str, IssueType] = {
     # 'AvoidInstantiatingObjectsInLoops': IssueType.BEST_PRACTICES,
     # 'AvoidUsingShortType': IssueType.BEST_PRACTICES,
     # 'BigIntegerInstantiation': IssueType.BEST_PRACTICES,
-    # 'BooleanInstantiation': IssueType.BEST_PRACTICES,
-    # 'ByteInstantiation': IssueType.BEST_PRACTICES,
     # 'InefficientEmptyStringCheck': IssueType.BEST_PRACTICES,
     # 'InsufficientStringBufferDeclaration': IssueType.BEST_PRACTICES,
-    # 'IntegerInstantiation': IssueType.BEST_PRACTICES,
-    # 'LongInstantiation': IssueType.BEST_PRACTICES,
     # 'RedundantFieldInitializer': IssueType.BEST_PRACTICES,
-    # 'ShortInstantiation': IssueType.BEST_PRACTICES,
     # 'SimplifyStartsWith': IssueType.BEST_PRACTICES,
     # 'StringInstantiation': IssueType.BEST_PRACTICES,
     # 'UseArrayListInsteadOfVector': IssueType.BEST_PRACTICES,
