@@ -5,19 +5,25 @@ from typing import Any, Dict, List, Optional
 
 from hyperstyle.src.python.review.common.subprocess_runner import run_in_subprocess
 from hyperstyle.src.python.review.inspectors.base_inspector import BaseInspector
+from hyperstyle.src.python.review.inspectors.common.base_issue_converter import convert_base_issue
 from hyperstyle.src.python.review.inspectors.inspector_type import InspectorType
-from hyperstyle.src.python.review.inspectors.issue import CodeIssue, IssueDifficulty, IssueType
+from hyperstyle.src.python.review.inspectors.issue import BaseIssue, IssueDifficulty, IssueType
+from hyperstyle.src.python.review.inspectors.issue_configs import IssueConfigsHandler
+from hyperstyle.src.python.review.inspectors.pylint.issue_configs import ISSUE_CONFIGS
 from hyperstyle.src.python.review.inspectors.pylint.issue_types import CATEGORY_TO_ISSUE_TYPE, CODE_TO_ISSUE_TYPE
-from hyperstyle.src.python.review.inspectors.tips import add_complexity_tip
 
 logger = logging.getLogger(__name__)
 
 MSG_TEMPLATE = '{abspath}:{line}:{column}:{msg_id}:{msg}'
 PATH_PYLINT_CONFIG = Path(__file__).parent / 'pylintrc'
 
+FATAL_CATEGORY = 'F'
+INFO_CATEGORY = 'I'
+
 
 class PylintInspector(BaseInspector):
     inspector_type = InspectorType.PYLINT
+    # noqa: SC100 TODO: Do not ignore complexity issues and add a complexity tip for R0915.
     supported_issue_types = (
         IssueType.CODE_STYLE,
         IssueType.BEST_PRACTICES,
@@ -25,7 +31,7 @@ class PylintInspector(BaseInspector):
     )
 
     @classmethod
-    def inspect(cls, path: Path, config: Dict[str, Any]) -> List[CodeIssue]:
+    def inspect(cls, path: Path, config: Dict[str, Any]) -> List[BaseIssue]:
         command = [
             'pylint',
             '--load-plugins', 'pylint_django',
@@ -38,49 +44,42 @@ class PylintInspector(BaseInspector):
         return cls.parse(output)
 
     @classmethod
-    def parse(cls, output: str) -> List[CodeIssue]:
-        fatal_category = 'F'
-        info_category = 'I'
+    def parse(cls, output: str) -> List[BaseIssue]:
         row_re = re.compile(r'^(.*):(\d+):(\d+):([IRCWEF]\d+):(.*)$', re.M)
+        issue_configs_handler = IssueConfigsHandler(*ISSUE_CONFIGS)
 
-        issues: List[CodeIssue] = []
-
+        issues = []
         for groups in row_re.findall(output):
-            if groups[1] == info_category:
+            if groups[1] == INFO_CATEGORY:
                 continue
 
-            if groups[1] == fatal_category:
+            if groups[1] == FATAL_CATEGORY:
                 logger.error('pylint encountered fatal error')
                 return issues
 
             origin_class = groups[3]
-            description = groups[4]
-            if origin_class == 'R0915':
-                description = add_complexity_tip(description)
-            elif origin_class == 'W1404':
-                description = 'Found implicit string concatenation. If you want to concatenate strings, use "+".'
-            elif origin_class == 'R1721':
-                description = (
-                    'Unnecessary use of a comprehension. Instead of using an identity comprehension, '
-                    'consider using the list, dict or set constructor. It is faster and simpler. '
-                    'For example, instead of {key: value for key, value in list_of_tuples} use dict(list_of_tuples).'
-                )
-
-            issue_type = cls.choose_issue_type(groups[3])
+            issue_type = cls.choose_issue_type(origin_class)
             if issue_type not in cls.supported_issue_types:
                 logger.error('pylint: unsupported issue type %s', issue_type.__name__)
                 continue
 
-            issues.append(CodeIssue(
+            base_issue = BaseIssue(
+                origin_class=origin_class,
+                type=issue_type,
+                description=groups[4],
                 file_path=Path(groups[0]),
                 line_no=int(groups[1]),
                 column_no=int(groups[2]) + 1,
-                origin_class=origin_class,
-                description=description,
                 inspector_type=cls.inspector_type,
-                type=issue_type,
                 difficulty=IssueDifficulty.get_by_issue_type(issue_type),
-            ))
+            )
+
+            issue = convert_base_issue(base_issue, issue_configs_handler)
+            if issue is None:
+                logger.error(f'{cls.inspector_type.value}: an error occurred during converting a base issue.')
+                continue
+
+            issues.append(issue)
 
         return issues
 
