@@ -17,3 +17,11 @@ PYTHON_AST_DATA_FOLDER = CURRENT_TEST_DATA_FOLDER / 'python_ast'
 CHECKSTYLE_DATA_FOLDER = CURRENT_TEST_DATA_FOLDER / 'checkstyle'
 
 PMD_DATA_FOLDER = CURRENT_TEST_DATA_FOLDER / 'pmd'
+
+FLAKE_DATA_FOLDER = CURRENT_TEST_DATA_FOLDER / 'flake8'
+
+PYLINT_DATA_FOLDER = CURRENT_TEST_DATA_FOLDER / 'pylint'
+
+DETEKT_DATA_FOLDER = CURRENT_TEST_DATA_FOLDER / 'detekt'
+
+ESLINT_DATA_FOLDER = CURRENT_TEST_DATA_FOLDER / 'eslint'
